============================
hostsmgr (Hosts Manager)
============================


.. image:: https://img.shields.io/pypi/v/hostsmgr.svg
        :target: https://pypi.python.org/pypi/hostsmgr

.. image:: https://img.shields.io/travis/starofrainnight/hostsmgr.svg
        :target: https://travis-ci.org/starofrainnight/hostsmgr

.. image:: https://ci.appveyor.com/api/projects/status/lx6dwcisa6bolsqw?svg=true
        :target: https://ci.appveyor.com/project/starofrainnight/hostsmgr

.. image:: https://readthedocs.org/projects/hostsmgr/badge/?version=latest
        :target: https://hostsmgr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/starofrainnight/hostsmgr/shield.svg
     :target: https://pyup.io/repos/github/starofrainnight/hostsmgr/
     :alt: Updates


API for manage hosts file


* Free software: Apache-2.0
* Documentation: https://hostsmgr.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `PyPackageTemplate`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`PyPackageTemplate`: https://github.com/starofrainnight/rtpl-pypackage

